struct PSInput
{
	float4 Position : SV_POSITION;
	float4 PosInWorld : TEXCOORD0;
	float4 Color : COLOR;
	float3 Normal : NORMAL;
	float2 UV : TEXCOORD;
	float3x3 TBN;
};

struct PSOutput
{
	float4 P : SV_TARGET0;
	float3 N : SV_TARGET1;
	float4 AS : SV_TARGET2;
};

SamplerState ss;
#ifdef SHADERED_DESKTOP
Texture2D gTextures[10] : register(t0);
float3 GetTexture(int id, float2 UV)
{
	return gTextures[id].Sample(ss, UV).rgb;
}
#else
Texture2D gTexture : register(t0);
Texture2D gNormal : register(t1);
float4 GetTexture(int id, float2 UV)
{
	return gTexture.Sample(ss, UV);
}
float3 GetNormal(float2 UV)
{
	return gNormal.Sample(ss, UV);
}
#endif



cbuffer Material : register(b0)
{
	int texture_id;
	int normal_id;
	float uv_x;
	float uv_y;
	bool has_normal;
};

PSOutput main(PSInput pin)
{
	PSOutput pout;
	pout.P = pin.PosInWorld;
	
	float2 UV = float2(uv_x, uv_y) * pin.UV;
	
	float3 n = pin.Normal;

	pout.N = normalize(GetNormal(UV).rgb);
	pout.N = normalize(pout.N*2 - 1);
	pout.N = float4(mul(pout.N.xyz, pin.TBN),1);
	pout.AS.rgb = GetTexture(texture_id, UV).rgb;
	pout.AS.a = 1;
	//pout.Color2 = pin.Color;
	
	return pout;
}